@@ -3,4 +3,4 @@ from __future__ import absolute_import
 # flake8: noqa
 
 # import apis into api package
-from hubspot.cms.blogs.blog_posts.api.blog_post_api import BlogPostApi
+from hubspot.cms.blogs.blog_posts.api.blog_posts_api import BlogPostsApi
